@@ -84,7 +84,7 @@
 #define KIOGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOGUI_NO_DEPRECATED
-#  define KIOGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KIOGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KIOGUI_NO_DEPRECATED_WARNINGS
 #  define KIOGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KIOGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOGUI_DEPRECATED_WARNINGS_SINCE KIOGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOGUI_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KIOGUI_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
